suffix

# XMLRésuméLibrary: User Guide

suburb | Element Reference | surname

## Name

suffix — A suffix of a name, usually specifying lineage

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `suffix` element contains a suffix or suffix abbreviation that follows a name, such as “Jr.”, “Senior”, or “III”.

### Parents

`suffix` may be contained in these elements: `name`

## Examples

    <name>
      <firstname>Leonard</firstname>
      <middlenames>Scott Quink</middlenames>
      <surname>Waggenblast</surname>
      <suffix>IV</suffix>
    </name>

    <name>
      <firstname>Dolores</firstname>
      <surname>Sanchez</surname>
      <suffix>Jr.</suffix>
    </name>

suburb | Element Reference | surname